@@ -1,23 +1,29 @@
-ADCV <- function(x,MaxLag=15){ 
+ADCV <- function(x,MaxLag=15,unbiased=FALSE){
     n <- length(x)
     if (is.matrix(x)) {
-        if (!NCOL(x) == 1) 
+        if (!NCOL(x) == 1)
             stop("Univariate time series only")
     }
     else {
         x <- c(x)
     }
-    if (!is.numeric(x)) 
+    if (!is.numeric(x))
         stop("'x' must be numeric")
-    if (!all(is.finite(x))) 
+    if (!all(is.finite(x)))
         stop("Missing or infitive values")
     if((MaxLag<0) | (MaxLag>(n-1)))stop("'MaxLag' must be in the range of 0 and (n-1)")
+    if ((unbiased==TRUE) && (n<3))stop("Sample size must be larger than 3")
     adcv <- matrix(0, 1,MaxLag+1,dimnames=list("  ",paste("lag",0:MaxLag)))
     for (k in seq(0,MaxLag,by=1)){
      xA <- x[1:(n-k)]
      xB <- x[(1+k):n]
-     adcv[,(k+1)] <- round(dcov(xA,xB),4)
-    }
+     if (unbiased) {
+      adcv[,(k+1)] <- round(dcovU(xA,xB),4)
+     }
+     else {
+      adcv[,(k+1)] <- round(dcov(xA,xB),4)
+     }
+     }
     return(adcv)
 }
 
