@@ -1,11 +1,16 @@
-SubsCV <- function(x,MaxLag,parallel){
+SubsCV <- function(x,MaxLag,parallel=FALSE){
  n <- length(x)
  if (((n-MaxLag)<0) || ((n-MaxLag)<4) || ((n-MaxLag)<=25)) stop("Give bigger sample size n")
+ dcorFun <- function(x,k,b){
+     xA <- x[1:(b-k)]
+     xB <- x[(1+k):b]
+     return(dcor(xA,xB))
+ }
  test <- function(x,j,b){
-  q <- n-b+1 
+  q <- n-b+1
   q <- ifelse(q<0,abs(q),q)
   Xb <- sapply(1:q, function(i) x[i:(i+b-1)])
-  Vx <- unlist(lapply(1:q, FUN=function(i) ADCF(Xb[,i],MaxLag=j)[j+1]^2))
+  Vx <- unlist(lapply(1:q, FUN=function(i) dcorFun(x=Xb[,i],k=j,b)^2))
   Vstar <- sort(Vx)
   la <- ceiling((1-0.05)*q)
   critical.value <- sqrt((b-j)*Vstar[la]/(n-j))
@@ -19,7 +24,7 @@ SubsCV <- function(x,MaxLag,parallel){
   se <- rep(0,length(bseq))
   for (l in 1:length(bseq)){
    bk <- bseq[l]+seq(-r,r,by=1)
-   Tneighb <- sapply(1:length(bk), function(m) test(x,j=lags,b=bk[m]))  
+   Tneighb <- sapply(1:length(bk), function(m) test(x,j=lags,b=bk[m]))
    se[l] <- (sum(abs(Tneighb-mean(Tneighb))^2)/(length(bk)-1))^(1/2)
   }
   smallest <- order(se)[1]
@@ -33,7 +38,7 @@ SubsCV <- function(x,MaxLag,parallel){
   registerDoParallel(cl)
   clusterSetRNGStream(cl = cl, iseed = 9182)
   i <- 1:MaxLag
-  fe_call <- as.call( c(list (as.name("foreach"), i = i,.combine="c",.export=c("ADCF","dcor")) ))
+  fe_call <- as.call( c(list (as.name("foreach"), i = i,.combine="c",.export=c("dcor")) ))
   fe <- eval(fe_call)
   cv <- fe %dopar% test(x,i,b=optimal.block(x,lags=i,MaxLag))
   stopCluster(cl)
