@@ -1,7 +1,7 @@
-TstarBoot1 <- function(x,type,p,b,parallel=FALSE){  
+TstarBoot1 <- function(x,type,p,b,parallel=FALSE){
  if(is.vector(x))stop('Multivariate time series only')
  if(!all(is.finite(x))) stop('Missing or infitive values')
- if (!is.numeric(x)) stop("'x' must be numeric") 
+ if (!is.numeric(x)) stop("'x' must be numeric")
  n <- as.integer(NROW(x))
  q <- as.integer(NCOL(x))
  MaxLag <- n-2
@@ -22,7 +22,8 @@ TstarBoot1 <- function(x,type,p,b,parallel=FALSE){
        Vrm[l,f] <- sqrt((Wtstar%*%(Atilde[[l]]*Btilde[[f]])%*%t(Wtstar))/((n-j)^2))
      }
    }
-   (n-j)*kern^2*sum(Vrm^2)
+    res <- (n-j)*kern^2*sum(Vrm^2)
+   return(res)
   }
   d=replicate(b,boot(Atilde,Btilde,j))
  }
