@@ -1,13 +1,13 @@
-mADCF <- function(x,lags,output=TRUE){
+mADCF <- function(x,lags,unbiased=FALSE,output=TRUE){
  if(!is.matrix(x)) x <- as.matrix(x)
  if ((is.data.frame(x)) | (is.matrix(x))){
   if(NCOL(x)==1)stop('Only multivariate time series with dimension d>2')
   if(!is.ts(x)) x <- as.ts(x)
  }
- if (!is.numeric(x)) 
+ if (!is.numeric(x))
      stop("'x' must be numeric")
  if(!all(is.finite(x))) stop('Missing or infitive values')
- if (missing(lags)) 
+ if (missing(lags))
        stop("'lags' is missing with no default")
  n <- as.integer(NROW(x))
  d <- as.integer(NCOL(x))
@@ -23,9 +23,14 @@ mADCF <- function(x,lags,output=TRUE){
  cross.adcf <- matrix(NA,d,d)
  for (i in 1:d){
   for (j in 1:d){
+   if (unbiased){
+    cross.adcf[i,j] <- bcdcor(X[,i],Y[,j])
+   }
+   else {
    cross.adcf[i,j] <- dcor(X[,i],Y[,j])
   }
  }
+ }
  if(output){
  cat("Distance Correlation Matrix at lag: ", lags, "\n")
  print(cross.adcf)
